@@ -62,7 +62,7 @@ ma_r_bb <- ma_r_barebones <- function(r, n, n_adj = NULL, sample_id = NULL, cite
                citekey <- match_variables(call = call_full[[match("citekey",  names(call_full))]], arg = citekey, arg_name = "citekey", data = data)
 
           if(deparse(substitute(moderators))[1] != "NULL")
-               moderators <- match_variables(call = call_full[[match("moderators",  names(call_full))]], arg = moderators, arg_name = "moderators", data = as_tibble(data), as_array = TRUE)
+               moderators <- match_variables(call = call_full[[match("moderators",  names(call_full))]], arg = moderators, arg_name = "moderators", data = as_tibble(data, .name_repair = "minimal"), as_array = TRUE)
      }
 
      if(!is.null(moderators)){
@@ -77,12 +77,12 @@ ma_r_bb <- ma_r_barebones <- function(r, n, n_adj = NULL, sample_id = NULL, cite
           moderator_names <- lapply(moderator_names, function(x) if(length(x) == 0){NULL}else{x})
 
           if(any(cat_moderators)){
-               moderator_levels <- lapply(as_tibble(moderators)[,cat_moderators], function(x){
+               moderator_levels <- lapply(as_tibble(moderators, .name_repair = "minimal")[,cat_moderators], function(x){
                     lvls <- levels(x)
                     if(is.null(lvls)) lvls <- levels(factor(x))
                     lvls
                })
-               names(moderator_levels) <- colnames(as_tibble(moderators)[,cat_moderators])
+               names(moderator_levels) <- colnames(as_tibble(moderators, .name_repair = "minimal")[,cat_moderators])
           }else{
                moderator_levels <- NULL
           }
