@@ -76,10 +76,14 @@ sensitivity <- function(ma_obj, leave1out = TRUE, bootstrap = TRUE, cumulative =
                         boot_iter = 1000, boot_conf_level = .95, 
                         boot_ci_type = c("bca", "norm", "basic", "stud", "perc"), ...){
 
+     psychmeta.show_progress <- options()$psychmeta.show_progress
+     if(is.null(psychmeta.show_progress)) psychmeta.show_progress <- TRUE
+
      flag_summary <- "summary.ma_psychmeta" %in% class(ma_obj)
      ma_obj <- screen_ma(ma_obj = ma_obj)
      
-     cat(" **** Computing sensitivity analyses **** \n")
+     if(psychmeta.show_progress)
+          cat(" **** Computing sensitivity analyses **** \n")
      bootstrap <- scalar_arg_warning(arg = bootstrap, arg_name = "bootstrap")
      leave1out <- scalar_arg_warning(arg = leave1out, arg_name = "leave1out")
      cumulative <- scalar_arg_warning(arg = cumulative, arg_name = "cumulative")
